@@ -1,5 +1,6 @@
 use crate::{
-    modules::{HttpFinding, HttpModule, Module},
+    modules::{HttpModule, Module, ModuleName, ModuleVersion},
+    report::{Finding, ModuleResult, Severity},
     Error,
 };
 use async_trait::async_trait;
@@ -14,22 +15,30 @@ impl KibanaUnauthenticatedAccess {
 }
 
 impl Module for KibanaUnauthenticatedAccess {
-    fn name(&self) -> String {
-        String::from("http/kibana_unauthenticated_access")
+    fn name(&self) -> ModuleName {
+        ModuleName::HttpKibanaUnauthenticatedAccess
     }
 
     fn description(&self) -> String {
         String::from("Check for Kibana Unauthenticated Access")
     }
+
+    fn version(&self) -> ModuleVersion {
+        ModuleVersion(1, 0, 0)
+    }
+
+    fn is_aggressive(&self) -> bool {
+        false
+    }
+
+    fn severity(&self) -> Severity {
+        Severity::High
+    }
 }
 
 #[async_trait]
 impl HttpModule for KibanaUnauthenticatedAccess {
-    async fn scan(
-        &self,
-        http_client: &Client,
-        endpoint: &str,
-    ) -> Result<Option<HttpFinding>, Error> {
+    async fn scan(&self, http_client: &Client, endpoint: &str) -> Result<Option<Finding>, Error> {
         let url = format!("{}", &endpoint);
         let res = http_client.get(&url).send().await?;
 
@@ -42,9 +51,12 @@ impl HttpModule for KibanaUnauthenticatedAccess {
         || body.contains(r#"<div class="ui-app-loading"><h1><strong>Kibana</strong><small>&nbsp;is loading."#)
         || Some(0) == body.find(r#"|| body.contains("#)
         || body.contains(r#"<div class="kibanaWelcomeLogo"></div></div></div><div class="kibanaWelcomeText">Loading Kibana</div></div>"#) {
-            return Ok(Some(HttpFinding::KibanaUnauthenticatedAccess(
-                url,
-            )));
+            return Ok(Some(Finding {
+                module: self.name(),
+                module_version: self.version(),
+                severity: self.severity(),
+                result: ModuleResult::Url(url),
+            }));
         }
 
         Ok(None)
